@@ -18,6 +18,7 @@ setGeneric("context", function(.Object, ...){standardGeneric("context")})
 #' 
 #' @param .Object a partition or a partitionBundle object
 #' @param query query, which may by a character vector or a cqpQuery object
+#' @param cqp defaults to is.cqp-function, or provide TRUE/FALSE
 #' @param pAttribute p-attribute of the query
 #' @param sAttribute if provided, it will be checked that cpos do not extend beyond
 #' the region defined by the s-attribute 
@@ -35,6 +36,7 @@ setGeneric("context", function(.Object, ...){standardGeneric("context")})
 #' @param mc whether to use multicore; if NULL (default), the function will get
 #'   the value from the options
 #' @param verbose report progress, defaults to TRUE
+#' @param progress logical, whether to show progress bar
 #' @param ... further parameters
 #' @return depending on whether a partition or a partitionBundle serves as
 #'   input, the return will be a context object, or a contextBundle object
@@ -45,10 +47,10 @@ setGeneric("context", function(.Object, ...){standardGeneric("context")})
 #'   context,cooccurrences-method
 #' @examples
 #' if (require(polmineR.sampleCorpus) && require(rcqp)){
+#'   use("polmineR.sampleCorpus")
 #'   p <- partition("PLPRBTTXT", list(text_type="speech"))
-#'   a <- context(p, "Integration", "word")
+#'   a <- context(p, query="Integration", pAttribute="word")
 #' }
-#' @importFrom parallel mclapply
 #' @import data.table
 #' @exportMethod context
 #' @rdname context-method
@@ -60,7 +62,7 @@ setMethod(
   signature(.Object="partition"),
   function
   (
-    .Object, query,
+    .Object, query, cqp=is.cqp,
     pAttribute=getOption("polmineR.pAttribute"),
     sAttribute=NULL,
     left=getOption("polmineR.left"),
@@ -69,15 +71,26 @@ setMethod(
     count=TRUE,
     method="ll",
     mc=getOption("polmineR.mc"),
-    verbose=TRUE
+    verbose=TRUE,
+    progress=FALSE
   ) {
     if (!identical(.Object@pAttribute, pAttribute) && !is.null(method)){
       message("... count for pAttribute ", pAttribute, " not available")
       .Object <- enrich(.Object, pAttribute=pAttribute)
     }
-    pAttr <- paste(.Object@corpus, ".", pAttribute, sep="")
-    sAttr <- .setMethod(left, right, sAttribute, corpus=.Object@corpus)[1]
-    cposMethod <- .setMethod(left, right, sAttribute, corpus=.Object@corpus)[2]
+
+    # set method for making left and right context
+    if (is.numeric(left) && is.numeric(right)){
+      if (is.null(names(left)) && is.null(names(left))){
+        cposMethod <- "expandToCpos"
+      } else {
+        cposMethod <- "expandBeyondRegion"
+        sAttribute <- unique(c(names(left), names(right)))
+      }
+    } else if (is.character(left) && is.character(right)){
+      cposMethod <- "expandToRegion"
+      sAttribute <- unique(c(left, right))
+    }
     
     # instantiate the context object
     ctxt <- new(
@@ -96,9 +109,9 @@ setMethod(
     
     # getting counts of query in partition
     .verboseOutput(message="getting cpos", verbose = verbose)
-    hits <- cpos(.Object, query, pAttribute[1])
+    hits <- cpos(.Object, query, pAttribute[1], cqp=cqp)
     if (is.null(hits)){
-      if (verbose==TRUE) message('no hits for query, returning NULL object')
+      warning('no hits for query ', query, ' returning NULL object')
       return(NULL)
     }
     if (!is.null(sAttribute)) hits <- cbind(hits, CQI$cpos2struc(.Object@corpus, sAttribute, hits[,1]))
@@ -115,11 +128,13 @@ setMethod(
     
     .verboseOutput(message="generating contexts", verbose = verbose)
     
-    if (mc==TRUE) {
-      bigBag <- mclapply(hits, function(x) .surrounding(x, ctxt, left, right, sAttr, stoplistIds, positivelistIds, cposMethod))
-    } else {
-      bigBag <- lapply(hits, function(x) .surrounding(x, ctxt, left, right, sAttr, stoplistIds, positivelistIds, cposMethod))
-    }
+    bigBag <- blapply(
+      hits, f=.surrounding,
+      mc=mc, progress=progress, verbose=verbose,
+      ctxt=ctxt, left=left, right=right, corpus=.Object@corpus, sAttribute=sAttribute,
+      stoplistIds=stoplistIds, positivelistIds=positivelistIds, method=cposMethod
+      )
+    
     bigBag <- bigBag[!sapply(bigBag, is.null)] # remove empty contexts
     if (!is.null(stoplistIds) || !is.null(positivelistIds)){
       if (verbose==TRUE) message("... hits filtered because stopword(s) occur / elements of positive list do not in context: ", (length(hits)-length(bigBag)))
@@ -162,38 +177,6 @@ setMethod(
   })
 
 
-.setMethod <- function(left, right, sAttribute, corpus){
-  if (is.numeric(left) && is.numeric(right)){
-    if (is.null(names(left)) && is.null(names(left))){
-      method <- "expandToCpos"
-      if (!is.null(sAttribute)) {
-        corpus.sAttribute <- paste(corpus, ".", sAttribute, sep="")
-      } else {
-        corpus.sAttribute <- NA
-      }
-    } else {
-      method <- "expandBeyondRegion"
-      sAttribute <- unique(c(names(left), names(right)))
-      if (length(sAttribute) == 1){
-        corpus.sAttribute <- paste(corpus, ".", sAttribute, sep="")
-      } else {
-        warning("please check names of left and right context provided")
-      }
-    }
-  } else if (is.character(left) && is.character(right)){
-    method <- "expandToRegion"
-    sAttribute <- unique(c(left, right))
-    if (length(sAttribute) == 1){
-      corpus.sAttribute <- paste(corpus, ".", sAttribute, sep="")
-    } else {
-      warning("please check names of left and right context provided")
-    }
-  }
-  return(c(corpus.sAttribute, method))
-}
-
-
-
 
 #' @param set a numeric vector with three items: left cpos of hit, right cpos of hit, struc of the hit
 #' @param left no of tokens to the left
@@ -203,29 +186,23 @@ setMethod(
 #' @noRd
 .makeLeftRightCpos <- list(
   
-  "expandToCpos" = function(set, left, right, corpus.sAttribute){
-    corpus <- strsplit(corpus.sAttribute, "\\.")[[1]][1]
-    sAttribute <- strsplit(corpus.sAttribute, "\\.")[[1]][2]
+  "expandToCpos" = function(set, left, right, corpus, sAttribute){
     cposLeft <- c((set[1] - left):(set[1]-1))
     cposRight <- c((set[2] + 1):(set[2] + right))
-    if (!is.na(corpus.sAttribute)){
-      cposLeft <- cposLeft[which(CQI$cpos2struc(corpus, sAttribute, cposLeft)==set[3])]
+    if (!is.null(sAttribute)){
+      cposLeft <- cposLeft[which(CQI$cpos2struc(corpus, sAttribute, cposLeft) == set[3])]
       cposRight <- cposRight[which(CQI$cpos2struc(corpus, sAttribute, cposRight)==set[3])]   
     }
     return(list(left=cposLeft, node=c(set[1]:set[2]), right=cposRight))
   },
   
-  "expandToRegion" = function(set, left, right, corpus.sAttribute){
-    corpus <- strsplit(corpus.sAttribute, "\\.")[[1]][1]
-    sAttribute <- strsplit(corpus.sAttribute, "\\.")[[1]][2]
+  "expandToRegion" = function(set, left, right, corpus, sAttribute){
     cposLeft <- c((CQI$cpos2lbound(corpus, sAttribute, set[1])):(set[1] - 1))
     cposRight <- c((set[2] + 1):(CQI$cpos2rbound(corpus, sAttribute, set[1])))
     return(list(left=cposLeft, node=c(set[1]:set[2]), right=cposRight))
   },
   
-  "expandBeyondRegion" = function(set, left, right, corpus.sAttribute){
-    corpus <- strsplit(corpus.sAttribute, "\\.")[[1]][1]
-    sAttribute <- strsplit(corpus.sAttribute, "\\.")[[1]][2]
+  "expandBeyondRegion" = function(set, left, right, corpus, sAttribute){
     queryStruc <- CQI$cpos2struc(corpus, sAttribute, set[1])
     maxStruc <- CQI$attribute_size(corpus, sAttribute)
     # get left min cpos
@@ -244,12 +221,10 @@ setMethod(
   
 )
 
-.surrounding <- function (set, ctxt, left, right, corpus.sAttribute, stoplistIds=NULL, positivelistIds=NULL, method) {
+.surrounding <- function (set, ctxt, left, right, corpus, sAttribute, stoplistIds=NULL, positivelistIds=NULL, method, ...) {
   cposList <- .makeLeftRightCpos[[method]](
-    set,
-    left=left,
-    right=right,
-    corpus.sAttribute=corpus.sAttribute
+    set, left=left, right=right,
+    corpus=corpus, sAttribute=sAttribute
     )
   cpos <- c(cposList$left, cposList$right)
   ids <- lapply(
@@ -330,7 +305,7 @@ setMethod("context", "cooccurrences", function(.Object, query, complete=FALSE){
       names(get(newObject@partition, ".GlobalEnv")@sAttributes)[[1]],
       sep=""
       )
-    hits <- .queryCpos(
+    hits <- cpos(
       newObject@query,
       get(newObject@partition, ".GlobalEnv"),
       pAttribute=newObject@pAttribute,
